@@ -28,7 +28,7 @@ main(int argc, char **argv)
     int		msec;
     char	*endnum;
     pmResult	*result;
-    pmResult	*prev = (pmResult *)0;
+    pmResult	*prev = NULL;
     int		i;
     int		numpmid = 3;
     pmID	pmid[3];
@@ -174,6 +174,8 @@ Options\n\
     }
 
     for (i = 0; i < samples; i++) {
+	struct timeval tmp;
+
 	sts = pmFetch(numpmid, pmid, &result);
 	if (sts < 0) {
 	    printf("sample[%d] pmFetch: %s\n", i, pmErrStr(sts));
@@ -183,7 +185,7 @@ Options\n\
 	    exit(1);
 	}
 	if (prev) {
-	    struct timeval tmp = result->timestamp;
+	    tmp = result->timestamp;
 	    pmtimevalDec(&tmp, &prev->timestamp);
 	    tdiff = pmtimevalToReal(&tmp);
 	    printf("\nsample %d, delta time=%.3f secs\n", i, tdiff);
@@ -229,7 +231,7 @@ Options\n\
 			    printf("event decode error: %s\n", pmErrStr(sts));
 			} else {
 			    for (r = 0; r < sts; r++) {
-				struct timeval tmp = records[r]->timestamp;
+				tmp = records[r]->timestamp;
 				pmtimevalDec(&tmp, &prev->timestamp);
 				tdiff = pmtimevalToReal(&tmp);
 				printf("\nevent %d, offset time=%.3f secs, param ids:", j+1, tdiff);
@@ -273,5 +275,11 @@ Options\n\
 
     printf("\n%d samples required %d log reads\n", i, __pmLogReads);
 
+    if (prev != NULL)
+	pmFreeResult(prev);
+
+    /* dump __pmResult pool if -Dalloc */
+    pmFreeResult(NULL);
+
     exit(0);
 }
