@@ -19,12 +19,10 @@
 #include "qmc.h"
 #include "qmc_desc.h"
 #include "qmc_group.h"
+#include "qmc_config.h"
 #include "qmc_context.h"
 
-#include <qlist.h>
 #include <qvector.h>
-#include <qstring.h>
-#include <qtextstream.h>
 
 class QmcMetricValue;
 
@@ -100,6 +98,7 @@ class QmcMetricValue
 {
 public:
     QmcMetricValue();
+    QmcMetricValue(const QmcMetricValue &);
     QmcMetricValue const& operator=(QmcMetricValue const& rhs);
 
     int instance() const { return my.instance; }
