@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014,2016, Red Hat.
+ * Copyright (c) 2014,2016,2021 Red Hat.
  * Copyright (c) 2006, Ken McDonell.  All Rights Reserved.
  * Copyright (c) 2007-2009, Aconex.  All Rights Reserved.
  * 
@@ -13,6 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  */
+#include <QScreen>
 #include <QSettings>
 #include <QStatusBar>
 #include <QApplication>
@@ -233,6 +234,14 @@ void writeSettings(void)
 	else
 	    userSettings.remove("savedHosts");
     }
+    if (globalSettings.lastArchivePathModified) {
+	globalSettings.lastArchivePathModified = false;
+	userSettings.setValue("lastArchivePath", globalSettings.lastArchivePath);
+    }
+    if (globalSettings.lastExportPathModified) {
+	globalSettings.lastExportPathModified = false;
+	userSettings.setValue("lastExportPath", globalSettings.lastExportPath);
+    }
 
     userSettings.endGroup();
 }
@@ -372,6 +381,21 @@ static void readSettings(void)
 	globalSettings.savedHosts =
 			userSettings.value("savedHosts").toStringList();
 
+    //
+    // Saved filesystem search paths
+    //
+    globalSettings.lastArchivePathModified = false;
+    QChar sep(pmPathSeparator());
+    QString pmlogger = QDir::toNativeSeparators(QDir::homePath());
+    pmlogger.append(sep).append(".pcp").append(sep).append("pmlogger");
+    globalSettings.lastArchivePath =
+    		userSettings.value("lastArchivePath", pmlogger).toString();
+    globalSettings.lastExportPathModified = false;
+    QString pictures = QDir::toNativeSeparators(QDir::homePath());
+    pictures.append(sep).append("Pictures");
+    globalSettings.lastExportPath =
+    		userSettings.value("lastExportPath", pictures).toString();
+
     userSettings.endGroup();
 }
 
@@ -416,7 +440,13 @@ static void setupViewGlobals()
     OpenViewDialog::globals(&w, &h, &points, &x, &y);
     if (w || h) {
 	QSize size = pmchart->size().expandedTo(QSize(w, h));
-	QSize desk = QApplication::desktop()->availableGeometry().size();
+	QSize desk;
+
+#if QT_VERSION >= 0x050000
+	desk = QApplication::primaryScreen()->availableGeometry().size();
+#else
+	desk = QApplication::desktop()->availableGeometry().size();
+#endif
 	pmchart->resize(size.boundedTo(desk));
     }
     if (x || y) {
@@ -468,6 +498,7 @@ main(int argc, char ** argv)
     QApplication a(argc, argv);
     setupEnvironment();
     readSettings();
+    atexit(writeSettings);
 
     opts.flags = PM_OPTFLAG_MULTI | PM_OPTFLAG_MIXED;
     opts.short_options = "A:a:Cc:D:f:F:g:h:H:Ln:o:O:p:s:S:T:t:Vv:WzZ:?";
@@ -608,15 +639,15 @@ main(int argc, char ** argv)
 			opts.nhosts, opts.narchives);
 
     if (opts.tzflag) {
-	if (opts.narchives > 0)
+	if (archiveGroup->numContexts() > 0)
 	    archiveGroup->useTZ();
-	if (opts.nhosts > 0)
+	if (liveGroup->numContexts() > 0)
 	    liveGroup->useTZ();
     }
     else if (opts.timezone != NULL) {
-	if (opts.narchives > 0)
+	if (archiveGroup->numContexts() > 0)
 	    archiveGroup->useTZ(QString(opts.timezone));
-	if (opts.nhosts > 0)
+	if (liveGroup->numContexts() > 0)
 	    liveGroup->useTZ(QString(opts.timezone));
 	if ((sts = pmNewZone(opts.timezone)) < 0) {
 	    pmprintf("%s: cannot set timezone to \"%s\": %s\n",
@@ -633,7 +664,7 @@ main(int argc, char ** argv)
     // set in that mode too.  Later we'll make a second connection
     // in the other mode (and only "on-demand").
     //
-    if (opts.narchives > 0) {
+    if (archiveGroup->numContexts() > 0) {
 	archiveGroup->defaultTZ(tzLabel, tzString);
 	archiveGroup->updateBounds();
 	logStartTime = archiveGroup->logStart();
@@ -654,7 +685,7 @@ main(int argc, char ** argv)
 	if (tcmp(&opts.origin, &opts.finish) > 0)
 	    opts.origin = opts.finish;
     }
-    else {
+    else if (liveGroup->numContexts() > 0) {
 	liveGroup->defaultTZ(tzLabel, tzString);
 	pmtimevalNow(&logStartTime);
 	logEndTime.tv_sec = logEndTime.tv_usec = INT_MAX;
