@@ -2,7 +2,7 @@
  * dstruct.c - central data structures and associated operations
  ***********************************************************************
  *
- * Copyright (c) 2013-2015 Red Hat.
+ * Copyright (c) 2013-2015,2020 Red Hat.
  * Copyright (c) 1995-2003 Silicon Graphics, Inc.  All Rights Reserved.
  * 
  * This program is free software; you can redistribute it and/or modify it
@@ -64,6 +64,7 @@ int		quiet;				/* suppress default diagnostics */
 int		verbose;			/* verbosity 0, 1 or 2 */
 int		interactive;			/* interactive mode, -d */
 int		isdaemon;			/* run as a daemon */
+int		systemd;			/* systemd mode, notify service manager */
 int		agent;				/* secret agent mode? */
 int		applet;				/* applet mode? */
 int		dowrap;				/* counter wrap? default no */
@@ -254,9 +255,11 @@ sleepTight(Task *t)
 	else {
 	    unrealizenano(delay, &ts);
 	    for (;;) {	/* loop to catch early wakeup from nanosleep */
-		if (ts.tv_sec < 0 || ts.tv_nsec > 999999999) {
-		    fprintf(stderr, "sleepTight: invalid args: %ld.%09ld\n",
-			    (long int)ts.tv_sec, (long int)ts.tv_nsec);
+		if (ts.tv_sec < 0 ||
+		    ts.tv_nsec < 0 || ts.tv_nsec > 999999999) {
+		    fprintf(stderr, "Botch: sleepTight: invalid args: delay=%f -> ts={%ld,%ld}\n",
+			    delay, (long int)ts.tv_sec, (long int)ts.tv_nsec);
+		    dumpTask(t);
 		    break;
 		}
 		sts = nanosleep(&ts, &tleft);
@@ -267,7 +270,39 @@ sleepTight(Task *t)
 		    logRotate();
 		    dorotate = 0;
 		}
-		if (sts == 0 || (sts < 0 && oserror() != EINTR))
+		if (sts == 0)
+		    break;
+		else if (sts < 0) {
+		    int	lsts = oserror();
+		    /*
+		     * error from nanosleep() .. be a bit anal here
+		     * because getting it wrong may lead to an infinite
+		     * loop
+		     */
+		    switch (lsts) {
+			case EINTR:
+			    /* interrupted, resume the sleep ... */
+			    break;
+			case ENOENT:
+			    /*
+			     * have seen this during pmie start up, not sure
+			     * of the cause, but seems safe to resume the
+			     * sleep ... */
+			    break;
+			default:
+			    fprintf(stderr, "sleepTight: nanosleep({%ld,%ld}) -> -1 errno=%d tleft={%ld,%ld}\n",
+				(long)ts.tv_sec, (long)ts.tv_nsec, lsts,
+				(long)tleft.tv_sec, (long)tleft.tv_nsec);
+			    sts = 0;	/* force end of for(;;) loop */
+			    break;
+		    }
+		}
+		else {
+		    fprintf(stderr, "Botch: sleepTight: nanosleep({%ld,%ld}) -> %d\n",
+				(long)ts.tv_sec, (long)ts.tv_nsec, sts);
+		    sts = 0;	/* force end of for(;;) loop */
+		}
+		if (sts == 0)
 		    break;
 		ts = tleft;
 	    }
@@ -495,17 +530,17 @@ newHost(Task *owner, Symbol name, Symbol conn)
 
 
 Task *
-newTask(RealTime delta, int nth)
+newTask(RealTime delta_arg, int nth)
 {
     Task *t = (Task *) zalloc(sizeof(Task));
     t->nth = nth;
-    t->delta = delta;
+    t->delta = delta_arg;
     return t;
 }
 
 /* translate new metric name to internal pmid for agent mode */
 static pmID
-agentId(char *name)
+agentId(const char *name)
 {
     int		sts;
     pmID	pmid;
@@ -1319,9 +1354,7 @@ void
 dumpTask(Task *t)
 {
     int	i;
-    Host	*h;
 
-    h = t->hosts;
     fprintf(stderr, "Task dump @ " PRINTF_P_PFX "%p\n", t);
     fprintf(stderr, "  nth=%d delta=%.3f tick=%d next=" PRINTF_P_PFX "%p prev=" PRINTF_P_PFX "%p\n", t->nth, t->delta, t->tick, t->next, t->prev);
     fprintf(stderr, "  eval time: ");
@@ -1332,15 +1365,16 @@ dumpTask(Task *t)
 	fprintf(stderr, "N/A");
     else
 	fprintf(stderr, "%.3f", t->retry);
-    if (h->down)
-	fprintf(stderr, " host %s down", symName(h->name));
-    else if (h->waits)
-	fprintf(stderr, " metric/instances missing");
-    fputc('\n', stderr);
     if (t->hosts == NULL)
-	fprintf(stderr, "  host=<null>\n");
-    else
-	fprintf(stderr, "  host=%s via=%s (%s)\n", symName(t->hosts->name), symName(t->hosts->conn), t->hosts->down ? "down" : "up");
+	fprintf(stderr, "  host: <null>\n");
+    else {
+	Host	*h = t->hosts;
+	fprintf(stderr, " host: %s", symName(h->name));
+	if (h->waits)
+	    fprintf(stderr, " metric/instances missing");
+	fputc('\n', stderr);
+	    fprintf(stderr, "  via=%s (%s)\n", symName(h->conn), h->down ? "down" : "up");
+    }
     fprintf(stderr, "  rules:\n");
     for (i = 0; i < t->nrules; i++) {
 	fprintf(stderr, "    %s\n", symName(t->rules[i]));
